TheiaAuth$new(auth.file) Create a new instance of the class
a$token() Return the current token or generate a next one if it has
expired
This class is used to manage authentication to Theia website, without
intervention from the user. Login and password must be stored in a
separate text file with these two lines:
login
password
File content is read each time authentication is needed (to request a new
token), so login and password are not stored in R's memory. If this file
does not exist, R will prompt you to enter your login and password and
will create the file.